@@ -1,5 +1,6 @@
 use crate::{
-    modules::{HttpFinding, HttpModule, Module},
+    modules::{HttpModule, Module, ModuleName, ModuleVersion},
+    report::{Finding, ModuleResult, Severity},
     Error,
 };
 use async_trait::async_trait;
@@ -14,22 +15,30 @@ impl GitlabOpenRegistrations {
 }
 
 impl Module for GitlabOpenRegistrations {
-    fn name(&self) -> String {
-        String::from("http/gitlab_open_registration")
+    fn name(&self) -> ModuleName {
+        ModuleName::HttpGitlabOpenRegistration
     }
 
     fn description(&self) -> String {
         String::from("Check if the GitLab instance is open to registrations")
     }
+
+    fn version(&self) -> ModuleVersion {
+        ModuleVersion(1, 0, 0)
+    }
+
+    fn is_aggressive(&self) -> bool {
+        false
+    }
+
+    fn severity(&self) -> Severity {
+        Severity::High
+    }
 }
 
 #[async_trait]
 impl HttpModule for GitlabOpenRegistrations {
-    async fn scan(
-        &self,
-        http_client: &Client,
-        endpoint: &str,
-    ) -> Result<Option<HttpFinding>, Error> {
+    async fn scan(&self, http_client: &Client, endpoint: &str) -> Result<Option<Finding>, Error> {
         let url = format!("{}", &endpoint);
         let res = http_client.get(&url).send().await?;
 
@@ -39,7 +48,12 @@ impl HttpModule for GitlabOpenRegistrations {
 
         let body = res.text().await?;
         if body.to_lowercase().contains("ref:") && body.contains("Register") {
-            return Ok(Some(HttpFinding::GitlabOpenRegistrations(url)));
+            return Ok(Some(Finding {
+                module: self.name(),
+                module_version: self.version(),
+                severity: self.severity(),
+                result: ModuleResult::Url(url),
+            }));
         }
 
         Ok(None)
